#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.illustration import IIllustration
from pyams_content.component.paragraph.interfaces.html import IRawParagraph, IHTMLParagraph
from pyams_content.features.renderer.interfaces import IContentRenderer
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.features.renderer.skin import BaseContentRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config

from pyams_default_theme import _


#
# Raw paragraph default renderer
#

@adapter_config(name='default', context=(IRawParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/raw-default.pt', layer=IPyAMSLayer)
class RawParagraphDefaultRenderer(BaseContentRenderer):
    """Raw paragraph default renderer"""

    label = _("Default raw HTML renderer")

    i18n_context_attrs = ('title', 'body', )


#
# HTML paragraph default renderer
#

@adapter_config(name='default', context=(IHTMLParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/html-default.pt', layer=IPyAMSLayer)
class HTMLParagraphDefaultRenderer(BaseContentRenderer):
    """HTML paragraph default renderer"""

    label = _("Default rich text renderer")

    i18n_context_attrs = ('title', 'body', )

    illustration = None
    illustration_renderer = None

    def update(self):
        super(HTMLParagraphDefaultRenderer, self).update()
        self.illustration = IIllustration(self.context)
        if self.illustration.data:
            renderer = self.illustration_renderer = self.illustration.get_renderer()
            if renderer is not None:
                renderer.update()

    def render_illustration(self):
        if not self.illustration_renderer:
            return ''
        return self.illustration_renderer.render()
